@@ -1,7 +1,7 @@
 from datetime import datetime
 
 import validators
-from ._odata_filter import _compose_filter
+from ._odata_filter import _compose_filter, _compose_select
 from ._str_match_algo import fuzzy_match
 from .guardpoint_dataclasses import Cardholder, SortAlgorithm
 from .guardpoint_error import GuardPointError
@@ -137,6 +137,26 @@ class CardholdersAPI:
         else:
             return self._get_card_holder(uid)
 
+    def get_card_holder_photo(self, uid):
+        if not validators.uuid(uid):
+            raise ValueError(f'Malformed UID {uid}')
+
+        url = "/odata/API_Cardholders"
+        url_query_params = "(" + uid + ")?$select=photo"
+
+        code, json_body = self.gp_json_query("GET", url=(url + url_query_params))
+        # Check response body is formatted correctly
+        if json_body:
+            GuardPointResponse.check_odata_body_structure(json_body)
+
+        if code != 200:
+            if isinstance(json_body, dict):
+                if 'error' in json_body:
+                    raise GuardPointError(json_body['error'])
+            else:
+                raise GuardPointError(str(code))
+
+        return json_body['value'][0]['photo']
     def _get_card_holder(self, uid):
         if not validators.uuid(uid):
             raise ValueError(f'Malformed UID {uid}')
@@ -168,7 +188,7 @@ class CardholdersAPI:
     def get_card_holders(self, offset: int = 0, limit: int = 10, search_terms: str = None, areas: list = None,
                          filter_expired: bool = False, cardholder_type_name: str = None,
                          sort_algorithm: SortAlgorithm = SortAlgorithm.SERVER_DEFAULT, threshold: int = 75,
-                         count: bool = False, earliest_last_pass: datetime = None):
+                         count: bool = False, earliest_last_pass: datetime = None, property_ignore_list: list = None):
 
         url = "/odata/API_Cardholders"
 
@@ -178,7 +198,10 @@ class CardholdersAPI:
                                      cardholder_type_name=cardholder_type_name,
                                      earliest_last_pass=earliest_last_pass)
 
-        url_query_params = ("?" + filter_str)
+        select_str = _compose_select(property_ignore_list)
+
+        url_query_params = ("?" + select_str + filter_str)
+        # url_query_params = ("?" + filter_str)
 
         if count:
             url_query_params += "$count=true&$top=0"
@@ -199,10 +222,13 @@ class CardholdersAPI:
             GuardPointResponse.check_odata_body_structure(json_body)
 
         if code != 200:
-            if 'error' in json_body:
-                raise GuardPointError(f"{json_body['error']} - ({code})")
+            if json_body:
+                if 'error' in json_body:
+                    raise GuardPointError(f"{json_body['error']} - ({code})")
+                else:
+                    raise GuardPointError(f"No error message - ({code})")
             else:
-                raise GuardPointError(f"No error message - ({code})")
+                raise GuardPointError(f"No body - ({code})")
 
         if count:
             return json_body['@odata.count']
